# st_switcher

Streamlit component that allows you to do X

## Installation instructions 

```sh
pip install st_switcher
```

## Usage instructions

```python
import streamlit as st

from st_switcher import st_switcher

value = st_switcher()

st.write(value)
